install.py

changeset 6637
54a92e8dca00
parent 6636
7ae6bdeb363d
child 6638
df711aa509d3
--- a/install.py	Sun Dec 16 17:48:09 2018 +0100
+++ b/install.py	Tue Dec 18 15:14:28 2018 +0100
@@ -548,7 +548,12 @@
                  if fnmatch.fnmatch(f, "*.pyc")]:
         os.remove(os.path.join(dirName, name))
     
-    # step 3: descent into subdirectories and delete them if empty
+    # step 3: delete *.orig files
+    for name in [f for f in os.listdir(dirName)
+                 if fnmatch.fnmatch(f, "*.orig")]:
+        os.remove(os.path.join(dirName, name))
+    
+    # step 4: descent into subdirectories and delete them if empty
     for name in os.listdir(dirName):
         name = os.path.join(dirName, name)
         if os.path.isdir(name):

eric ide

mercurial